/**
 * Memoize the given supplier so that it is called at most once.
 */
export const memoizeSupplier = (supplier) => {
    const name = supplier.name;
    let value;
    let done = false;
    return {
        [name]: () => {
            if (!done) {
                value = supplier();
                done = true;
            }
            return value;
        },
    }[name];
};
/**
 * Shorthand for {@link memoizeSupplier}.
 */
export const memoize = memoizeSupplier;
//# sourceMappingURL=memoize.js.map