/**
 * Add a property to the given object which is calculated lazily, and
 * only once.
 */
export const withLazyProperty = (target, name, calculator) => {
    Object.defineProperty(target, name, {
        configurable: true,
        enumerable: true,
        get() {
            const value = calculator(target);
            delete target[name];
            Object.defineProperty(target, name, {
                configurable: false,
                enumerable: true,
                value,
            });
            return value;
        },
    });
    return target;
};
//# sourceMappingURL=with-lazy-property.js.map