import type { Comparator } from "@rickosborne/typical";
import type { Queue } from "./queue.js";
/**
 * Internal implementation for a node of a skip list.
 * @internal
 */
type SkipNode<T> = {
    forward: (SkipNode<T> | undefined)[];
    value: T;
};
/**
 * Basic skip list implementation, using the given comparator
 * to keep values in order, low-to-high.  If you want high-to-low
 * you will need to invert your comparator.
 */
export declare class SkipList<T> implements Queue<T> {
    protected readonly comparator: Comparator<T>;
    protected readonly maxLevel: number;
    protected readonly random: () => number;
    private count;
    private level;
    private readonly root;
    constructor(comparator: Comparator<T>, maxLevel?: number, random?: () => number);
    get length(): number;
    add(value: T): void;
    protected buildNode(value: T, level: number): SkipNode<T>;
    private buildUpdate;
    peek(): T | undefined;
    protected randomLevel(): number;
    remove(value: T): void;
    take(): T | undefined;
    toArray(): T[];
    values(): Generator<T, void, undefined>;
    valuesAndIndexes(): Generator<[T, number], void, undefined>;
}
/**
 * Build a priority queue using a skip list implementation.
 */
export declare const skipList: <T>(comparator: Comparator<T>) => SkipList<T>;
export {};
//# sourceMappingURL=skip-list.d.ts.map