"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.withLazyProperty = void 0;
/**
 * Add a property to the given object which is calculated lazily, and
 * only once.
 */
const withLazyProperty = (target, name, calculator) => {
    Object.defineProperty(target, name, {
        configurable: true,
        enumerable: true,
        get() {
            const value = calculator(target);
            delete target[name];
            Object.defineProperty(target, name, {
                configurable: false,
                enumerable: true,
                value,
            });
            return value;
        },
    });
    return target;
};
exports.withLazyProperty = withLazyProperty;
//# sourceMappingURL=with-lazy-property.js.map